The original patch used incorrect subnet range for testing.

Fixes: 37afe381bde4 ("examples/l3fwd: use reserved IP addresses")
Reported-by: Ferruh Yigit <ferruh.yi...@intel.com>
Signed-off-by: Stephen Hemminger <step...@networkplumber.org>
---
 doc/guides/testpmd_app_ug/run_app.rst |  6 +++---
 examples/l3fwd/l3fwd_lpm.c            | 18 +++++++++---------
 2 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/doc/guides/testpmd_app_ug/run_app.rst 
b/doc/guides/testpmd_app_ug/run_app.rst
index 00e0c2ac5152..858cec7e0b0b 100644
--- a/doc/guides/testpmd_app_ug/run_app.rst
+++ b/doc/guides/testpmd_app_ug/run_app.rst
@@ -129,9 +129,9 @@ The command line options are:
 *   ``--tx-ip=SRC,DST``
 
     Set the source and destination IP address used when doing transmit only 
test.
-    The defaults address values are source 192.18.0.1 and
-    destination 192.18.0.2. These are special purpose addresses
-    reserved for benchmarking (RFC 2544).
+    The defaults address values are source 198.18.0.1 and
+    destination 198.18.0.2. These are special purpose addresses
+    reserved for benchmarking (RFC 5735).
 
 *   ``--tx-udp=SRC[,DST]``
 
diff --git a/examples/l3fwd/l3fwd_lpm.c b/examples/l3fwd/l3fwd_lpm.c
index a3a65f7fc814..349de2703cd1 100644
--- a/examples/l3fwd/l3fwd_lpm.c
+++ b/examples/l3fwd/l3fwd_lpm.c
@@ -41,16 +41,16 @@ struct ipv6_l3fwd_lpm_route {
        uint8_t  if_out;
 };
 
 /* 192.18.0.0/16 are set aside for RFC2544 benchmarking. */
 static struct ipv4_l3fwd_lpm_route ipv4_l3fwd_lpm_route_array[] = {
-       {RTE_IPV4(192, 18, 0, 0), 24, 0},
-       {RTE_IPV4(192, 18, 1, 0), 24, 1},
-       {RTE_IPV4(192, 18, 2, 0), 24, 2},
-       {RTE_IPV4(192, 18, 3, 0), 24, 3},
-       {RTE_IPV4(192, 18, 4, 0), 24, 4},
-       {RTE_IPV4(192, 18, 5, 0), 24, 5},
-       {RTE_IPV4(192, 18, 6, 0), 24, 6},
-       {RTE_IPV4(192, 18, 7, 0), 24, 7},
+       {RTE_IPV4(198, 18, 0, 0), 24, 0},
+       {RTE_IPV4(198, 18, 1, 0), 24, 1},
+       {RTE_IPV4(198, 18, 2, 0), 24, 2},
+       {RTE_IPV4(198, 18, 3, 0), 24, 3},
+       {RTE_IPV4(198, 18, 4, 0), 24, 4},
+       {RTE_IPV4(198, 18, 5, 0), 24, 5},
+       {RTE_IPV4(198, 18, 6, 0), 24, 6},
+       {RTE_IPV4(198, 18, 7, 0), 24, 7},
 };
 
 /* 2001:0200::/48 is IANA reserved range for IPv6 benchmarking (RFC5180) */
@@ -41,16 +41,16 @@ struct ipv6_l3fwd_lpm_route {
 };
 
-/* 192.18.0.0/16 are set aside for RFC2544 benchmarking. */
+/* 198.18.0.0/16 are set aside for RFC2544 benchmarking (RFC5735). */
 static struct ipv4_l3fwd_lpm_route ipv4_l3fwd_lpm_route_array[] = {
-- 
2.20.1

Reply via email to